==> keycloak-model-map-18.0.2-sources.jar: org/keycloak/models/map/realm/entity/MapAuthenticatorConfigEntityDelegate.java <==
package org.keycloak.models.map.realm.entity;
public class MapAuthenticatorConfigEntityDelegate implements org.keycloak.models.map.realm.entity.MapAuthenticatorConfigEntity {
    private final org.keycloak.models.map.common.delegate.DelegateProvider<org.keycloak.models.map.realm.entity.MapAuthenticatorConfigEntity> delegateProvider;
    public MapAuthenticatorConfigEntityDelegate(org.keycloak.models.map.common.delegate.DelegateProvider<org.keycloak.models.map.realm.entity.MapAuthenticatorConfigEntity> delegateProvider) {
        this.delegateProvider = delegateProvider;
    }
    @Override public boolean isUpdated() {
        return delegateProvider.isUpdated();
    }
    @Override public String getId() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.realm.entity.MapAuthenticatorConfigEntityFields.ID).getId();
    }
    @Override public void setId(String id) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.realm.entity.MapAuthenticatorConfigEntityFields.ID, id).setId(id);
    }
    @Override public String getAlias() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.realm.entity.MapAuthenticatorConfigEntityFields.ALIAS).getAlias();
    }
    @Override public void setAlias(String alias) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.realm.entity.MapAuthenticatorConfigEntityFields.ALIAS, alias).setAlias(alias);
    }
    @Override public java.util.Map<String,String> getConfig() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.realm.entity.MapAuthenticatorConfigEntityFields.CONFIG).getConfig();
    }
    @Override public void setConfig(java.util.Map<String,String> config) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.realm.entity.MapAuthenticatorConfigEntityFields.CONFIG, config).setConfig(config);
    }
}

==> keycloak-model-map-21.0.0-sources.jar: org/keycloak/models/map/realm/entity/MapAuthenticatorConfigEntityDelegate.java <==
package org.keycloak.models.map.realm.entity;
@javax.annotation.processing.Generated("org.keycloak.models.map.processor.GenerateEntityImplementationsProcessor")
public class MapAuthenticatorConfigEntityDelegate implements org.keycloak.models.map.realm.entity.MapAuthenticatorConfigEntity, org.keycloak.models.map.common.delegate.HasDelegateProvider<org.keycloak.models.map.realm.entity.MapAuthenticatorConfigEntity> {
    private final org.keycloak.models.map.common.delegate.DelegateProvider<org.keycloak.models.map.realm.entity.MapAuthenticatorConfigEntity> delegateProvider;
    public MapAuthenticatorConfigEntityDelegate(org.keycloak.models.map.common.delegate.DelegateProvider<org.keycloak.models.map.realm.entity.MapAuthenticatorConfigEntity> delegateProvider) {
        this.delegateProvider = delegateProvider;
    }
    public org.keycloak.models.map.common.delegate.DelegateProvider<org.keycloak.models.map.realm.entity.MapAuthenticatorConfigEntity> getDelegateProvider() {
        return this.delegateProvider;
    }
    @Override public boolean isUpdated() {
        return delegateProvider.isUpdated();
    }
    @Override public String getId() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.realm.entity.MapAuthenticatorConfigEntityFields.ID).getId();
    }
    @Override public void setId(String id) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.realm.entity.MapAuthenticatorConfigEntityFields.ID, id).setId(id);
    }
    @Override public String getAlias() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.realm.entity.MapAuthenticatorConfigEntityFields.ALIAS).getAlias();
    }
    @Override public void setAlias(String alias) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.realm.entity.MapAuthenticatorConfigEntityFields.ALIAS, alias).setAlias(alias);
    }
    @Override public java.util.Map<String,String> getConfig() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.realm.entity.MapAuthenticatorConfigEntityFields.CONFIG).getConfig();
    }
    @Override public void setConfig(java.util.Map<String,String> config) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.realm.entity.MapAuthenticatorConfigEntityFields.CONFIG, config).setConfig(config);
    }
}
